@@ -3,7 +3,7 @@
 2008-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 '''
  
-def get_formatted_time(s_time, format=0):
+def get_formatted_time(ctime, format=0):
 
   def print_format(value, add_zero=True):
     if add_zero and value < 10:
@@ -12,15 +12,15 @@ def get_formatted_time(s_time, format=0):
       return '%s' % value
 
   tmp = ''
-  if s_time >= pow(60, 3):
-    s_time %= pow(60, 3)
   a_time = []
+  s_time = ctime
   for i in range(0,3):
     c_time = s_time%60
-    s_time = s_time - c_time
+    s_time -= c_time
     a_time.append(c_time)
     s_time /= 60
   a_time.reverse()
+  a_time[0] = ctime / pow(60, 2)
   a_time = a_time[0:(len(a_time)-format)]
   if a_time[0] == 0:
     tmp = '%s:%s' % (a_time[len(a_time)-2], print_format(a_time[len(a_time)-1]))
